@@ -115,6 +115,26 @@ namespace libsemigroups {
       m.def("normalize_alphabet", &presentation::normalize_alphabet<T>);
       m.def("remove_redundant_generators",
             &presentation::remove_redundant_generators<T>);
+      m.def("add_zero_rules", &presentation::add_zero_rules<T>);
+      m.def("are_rules_sorted", &presentation::are_rules_sorted<T>);
+      m.def("change_alphabet", &presentation::change_alphabet<T>);
+      m.def("character", &presentation::character);
+      m.def("letter", &presentation::letter<T>);
+      m.def("first_unused_letter", &presentation::first_unused_letter<T>);
+      m.def("greedy_reduce_length", &presentation::greedy_reduce_length<T>);
+      m.def("longest_rule", [](Presentation<T> const& p) {
+        return std::distance(p.rules.cbegin(), presentation::longest_rule(p));
+      });
+      m.def("longest_rule_length", [](Presentation<T> const& p) {
+        return presentation::longest_rule_length(p);
+      });
+      m.def("shortest_rule", [](Presentation<T> const& p) {
+        return std::distance(p.rules.cbegin(), presentation::shortest_rule(p));
+      });
+      m.def("shortest_rule_length", [](Presentation<T> const& p) {
+        return presentation::shortest_rule_length(p);
+      });
+      m.def("make_semigroup", presentation::make_semigroup<T>);
 
       m.def(
           "make",
