@@ -20,9 +20,8 @@ import pytest
 from libsemigroups_pybind11 import (
     Presentation,
     ReportGuard,
-    libsemigroups_version,
     presentation,
-    compare_version_numbers,
+    UNDEFINED,
 )
 
 ###############################################################################
@@ -383,6 +382,81 @@ def check_redundant_rule(W):
     assert len(p.rules) == 84
 
 
+def check_longest_rule(W):
+    p = Presentation(W([]))
+    p.rules = [W([0, 1, 2, 1])]
+    with pytest.raises(RuntimeError):
+        assert presentation.longest_rule(p)
+
+    p.rules = [W([0, 1, 2, 1]), W([1, 2, 1])]
+    presentation.add_rule(p, W([1, 1, 2, 1]), W([1, 1]))
+    presentation.add_rule(p, W([1, 2, 1]), W([0]))
+    assert p.rules[presentation.longest_rule(p)] == W([0, 1, 2, 1])
+    assert p.rules[presentation.shortest_rule(p)] == W([1, 2, 1])
+
+
+def check_longest_rule_length(W):
+    p = Presentation(W([]))
+    p.rules = [W([0, 1, 2, 1])]
+    with pytest.raises(RuntimeError):
+        presentation.longest_rule_length(p)
+    p.rules = [W([0, 1, 2, 1]), W([1, 2, 1])]
+    presentation.add_rule(p, W([1, 1, 2, 1]), W([1, 1]))
+    presentation.add_rule(p, W([1, 2, 1]), W([0]))
+    assert presentation.longest_rule_length(p) == 7
+    assert presentation.shortest_rule_length(p) == 4
+
+
+def check_make_semigroup(W):
+
+    p = Presentation(W([]))
+    presentation.add_rule(p, W([0, 0]), W([]))
+    presentation.add_rule(p, W([1, 1]), W([]))
+    presentation.add_rule(p, W([2, 2]), W([]))
+    presentation.add_rule(p, W([0, 1, 0, 1, 0, 1]), W([]))
+    presentation.add_rule(p, W([1, 2, 1, 0, 1, 2, 1, 0]), W([]))
+    presentation.add_rule(p, W([2, 0, 2, 1, 2, 0, 2, 1]), W([0, 3]))
+
+    p.alphabet_from_rules()
+    e = presentation.make_semigroup(p)
+    assert p.rules == [
+        W([0, 0]),
+        W([e]),
+        W([1, 1]),
+        W([e]),
+        W([2, 2]),
+        W([e]),
+        W([0, 1, 0, 1, 0, 1]),
+        W([e]),
+        W([1, 2, 1, 0, 1, 2, 1, 0]),
+        W([e]),
+        W([2, 0, 2, 1, 2, 0, 2, 1]),
+        W([0, 3]),
+        W([0, e]),
+        W([0]),
+        W([e, 0]),
+        W([0]),
+        W([1, e]),
+        W([1]),
+        W([e, 1]),
+        W([1]),
+        W([2, e]),
+        W([2]),
+        W([e, 2]),
+        W([2]),
+        W([3, e]),
+        W([3]),
+        W([e, 3]),
+        W([3]),
+        W([e, e]),
+        W([e]),
+    ]
+    e = presentation.make_semigroup(p)
+    assert e in (UNDEFINED, "\x7f")
+    # TODO allow comparison of UNDEFINED and chars (or strings of length 1),
+    # and remove the "or" in the previous line
+
+
 ###############################################################################
 # Test functions begin
 ###############################################################################
@@ -628,17 +702,9 @@ def test_helpers_reduce_complements_016():
     assert p.rules == ["bb", "a", "bcb", "a", "abcb", "a", "bbcb", "a"]
     assert p.alphabet() == "abc"
     presentation.normalize_alphabet(p)
-    if (
-        compare_version_numbers(libsemigroups_version(), "2.5.2")
-        or p.letter(0) == "a"
-    ):
-        assert p.letter(0) == "a"
-        assert p.letter(1) == "b"
-        assert p.letter(2) == "c"
-    else:
-        assert p.letter(0) == "\x00"
-        assert p.letter(1) == "\x01"
-        assert p.letter(2) == "\x02"
+    assert p.letter(0) == "a"
+    assert p.letter(1) == "b"
+    assert p.letter(2) == "c"
 
     p.validate()
 
@@ -746,3 +812,168 @@ def test_helpers_replace_word():
     presentation.replace_word(p, [], [1])
     p.alphabet_from_rules()
     p.validate()
+
+
+def test_helpers_add_zero_rules():
+    p = Presentation("abc")
+    presentation.add_rule(p, "abcb", "aa")
+
+    with pytest.raises(RuntimeError):
+        presentation.add_zero_rules(p, "0")
+    p.alphabet("abc0")
+    presentation.add_zero_rules(p, "0")
+    assert p.rules == [
+        "abcb",
+        "aa",
+        "a0",
+        "0",
+        "0a",
+        "0",
+        "b0",
+        "0",
+        "0b",
+        "0",
+        "c0",
+        "0",
+        "0c",
+        "0",
+        "00",
+        "0",
+    ]
+
+
+def test_helpers_are_rules_sorted():
+    p = Presentation("")
+    p.contains_empty_word(False)
+    p.alphabet("aAbBcCe")
+    presentation.add_inverse_rules(p, "AaBbCce", "e")
+    assert p.rules == [
+        "aA",
+        "e",
+        "Aa",
+        "e",
+        "bB",
+        "e",
+        "Bb",
+        "e",
+        "cC",
+        "e",
+        "Cc",
+        "e",
+    ]
+
+    assert not presentation.are_rules_sorted(p)
+    presentation.sort_rules(p)
+    assert presentation.are_rules_sorted(p)
+
+
+def test_change_alphabet():
+    p = Presentation("")
+    p.alphabet("ab")
+    presentation.add_rule_and_check(p, "ba", "abaaabaa")
+    presentation.replace_subword(p, "ba")
+    presentation.change_alphabet(p, "abc")
+    assert p.rules == ["c", "acaaca", "c", "ba"]
+    assert p.alphabet() == "abc"
+    p.validate()
+    # Alphabet wrong size
+    with pytest.raises(RuntimeError):
+        presentation.change_alphabet(p, "ab")
+    with pytest.raises(RuntimeError):
+        presentation.change_alphabet(p, "aab")
+    assert p.alphabet() == "abc"
+    assert p.rules == ["c", "acaaca", "c", "ba"]
+    presentation.change_alphabet(p, "bac")
+    assert p.rules == ["c", "bcbbcb", "c", "ab"]
+    assert p.alphabet() == "bac"
+
+    presentation.change_alphabet(p, "xyz")
+    assert p.rules == ["z", "xzxxzx", "z", "yx"]
+    assert p.alphabet() == "xyz"
+
+    presentation.change_alphabet(p, "xyt")
+    assert p.rules == ["t", "xtxxtx", "t", "yx"]
+    assert p.alphabet() == "xyt"
+
+
+def test_character_letter():
+    p = Presentation("")
+    with pytest.raises(RuntimeError):
+        presentation.letter(p, 65536)
+
+    p = Presentation([])
+    assert presentation.letter(p, 10) == 10
+
+    p = Presentation("")
+    with pytest.raises(RuntimeError):
+        presentation.character(65536)
+    assert presentation.character(0) == "a"
+    assert presentation.character(10) == "k"
+
+    assert all(
+        presentation.character(i) == presentation.letter(p, i)
+        for i in range(0, 255)
+    )
+
+
+def test_first_unused_letter():
+    p = Presentation("ab")
+
+    presentation.add_rule_and_check(p, "baabaa", "ababa")
+    assert presentation.first_unused_letter(p) == "c"
+    p.alphabet("abcdefghijklmnopq")
+    assert presentation.first_unused_letter(p) == "r"
+    p.alphabet("abcdefghijklmnopqrstuvwxyz")
+    assert presentation.first_unused_letter(p) == "A"
+    p.alphabet("abcdefgijklmnopqrstuvwxyz")
+    assert presentation.first_unused_letter(p) == "h"
+    p.alphabet("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ")
+    assert presentation.first_unused_letter(p) == "0"
+    p.alphabet("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ02")
+    assert presentation.first_unused_letter(p) == "1"
+    letters = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789"
+    for i, c in enumerate(letters):
+        assert c == presentation.letter(p, i)
+
+    with pytest.raises(RuntimeError):
+        assert presentation.letter(p, 255)
+    p.alphabet(255)
+    with pytest.raises(RuntimeError):
+        assert presentation.first_unused_letter(p)
+    with pytest.raises(RuntimeError):
+        assert p.alphabet(256)
+
+
+def test_greedy_reduce_length():
+    p = Presentation("ab")
+    presentation.add_rule_and_check(p, "aaaaaaaaaaaaaaaa", "a")
+    presentation.add_rule_and_check(p, "bbbbbbbbbbbbbbbb", "b")
+    presentation.add_rule_and_check(p, "abb", "baa")
+    assert presentation.length(p) == 40
+    presentation.greedy_reduce_length(p)
+    assert presentation.length(p) == 26
+    assert p.rules == [
+        "dddd",
+        "a",
+        "cccc",
+        "b",
+        "abb",
+        "baa",
+        "c",
+        "bbbb",
+        "d",
+        "aaaa",
+    ]
+    assert presentation.longest_common_subword(p) == ""
+
+
+def test_longest_shortest_rule():
+    check_longest_rule(to_word)
+    check_longest_rule(to_string)
+    check_longest_rule_length(to_word)
+    check_longest_rule_length(to_string)
+
+
+def test_make_semigroup():
+    check_make_semigroup(to_word)
+    check_make_semigroup(to_string)
